@@ -191,9 +191,7 @@ to_sql.relop_order_expr <- function (x,
                                      tnum = mk_tmp_name_source('tsql'),
                                      append_cr = TRUE,
                                      using = NULL) {
-  if(length(list(...))>0) {
-    stop("rquery::to_sql.relop_order_expr unexpected arguments")
-  }
+  wrapr::stop_if_dot_args(substitute(list(...)), "rquery::to_sql.relop_order_expr")
   dispatch_to_sql_method(
     method_name = "to_sql.relop_order_expr",
     x = x,
